function SimSimDiceSq(Ns)
% Simulate a series of simulations, estimating variance of squared dice roll
%
% 
%________________________________________________________________________
% Script:   SimSimDiceSq.m
% Purpose:  Discrete r.v. simulation and variance calculation
% Author:   Tom Nichols
% Date:     8 Jan 2012
%

% For convenience, save this to a variable
nNs=length(Ns);
% How many times to simulate
nSim = 1000;

% Initialize min & max (for consistent plotting later)
MinVar = Inf;
MaxVar = -Inf;

% SimVa - Matrix to hold all the simulation
SimVa = zeros(nSim,nNs);

% Simulate all desired N's
for i=1:nNs
  Va=SimDiceSq(Ns(i),nSim);
  SimVa(:,i) = Va;
  % Record Max & Min
  if max(Va)>MaxVar
    MaxVar=max(Va);
  end
  if min(Va)<MinVar
    MinVar=min(Va);
  end
end


% Plot all results
for i=1:nNs
  subplot(nNs,1,i)
  hist(SimVa(:,i))
  set(gca,'xlim',[MinVar,MaxVar]);
  title(sprintf('Simulation with %d realizations',Ns(i)))
end
